<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>MEConfig</name>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <source>MX User Manager</source>
        <translation>MX User Manager </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <source>Administration</source>
        <translation>Administració </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="65"/>
        <source>Add a new user</source>
        <translation>Afegeix un usuari nou</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="105"/>
        <source>Add User Account</source>
        <translation>Afegeix compte d&apos;usuari </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="132"/>
        <source>Enter password for new user</source>
        <translation>Introduïu la contrasenya pel nou usuari </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="141"/>
        <source>password</source>
        <translation>contrasenya </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="173"/>
        <source>Reenter password for new user</source>
        <translation>Torneu a entrar la contrasenya pel nou usuari </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="182"/>
        <source>confirm password</source>
        <translation>confirmeu la contrasenya</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="198"/>
        <source>Username of new user</source>
        <translation>Nom del nou usuari </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="201"/>
        <source>User login name:</source>
        <translation>Nom d&apos;entrada de l&apos;usuari: </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="217"/>
        <location filename="../mainwindow.ui" line="466"/>
        <source>Enter username of new user</source>
        <translation>Entreu el nom del nou usuari </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="223"/>
        <location filename="../mainwindow.ui" line="472"/>
        <source>username</source>
        <translation>nomdusuari </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="239"/>
        <location filename="../mainwindow.ui" line="258"/>
        <source>Password for new user</source>
        <translation>Contrasenya pel nou usuari </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="242"/>
        <source>Confirm user password:</source>
        <translation>Confirmeu la contrasenya d&apos;usuari: </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="261"/>
        <source>User password:</source>
        <translation>Contrasenya d&apos;usuari: </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="271"/>
        <source>Grant this user administrative rights to the system (sudo)</source>
        <translation>Concedeix drets d&apos;administrador a aquest usuari (sudo)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="290"/>
        <source>Delete User Account</source>
        <translation>Elimina un compte d&apos;usuari </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="333"/>
        <source>Select user</source>
        <translation>Trieu l&apos;usuari</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="349"/>
        <location filename="../mainwindow.ui" line="1436"/>
        <source>Select user to delete</source>
        <translation>Trieu l&apos;usuari a eliminar </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="358"/>
        <source>User to delete:</source>
        <translation>Usuari a eliminar:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="374"/>
        <source>Also delete the user&apos;s home directory</source>
        <translation>Elimina també el directori personal </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="377"/>
        <source>Delete user home directory</source>
        <translation>Elimina el directori d&apos;inici de l&apos;usuari</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="396"/>
        <source>Rename User Account</source>
        <translation>Reanomena el compte d&apos;usuari</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="408"/>
        <location filename="../mainwindow.ui" line="570"/>
        <source>Select user to modify:</source>
        <translation>Trieu l&apos;usuari a modificar:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="450"/>
        <source>New user name:</source>
        <translation>Nou nom d&apos;usuari:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="491"/>
        <source>Change User Password</source>
        <translation>Canvia la contrasenya d&apos;usuari</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="519"/>
        <source>new password</source>
        <translation>nova contrasenya</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="535"/>
        <source>Confirm new password:</source>
        <translation>Confirmeu la nova contrasenya:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="554"/>
        <source>confirm new password</source>
        <translation>confirmeu la nova contrasenya</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="586"/>
        <source>New user password:</source>
        <translation>Nova contrasenya d&apos;usuari: </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="620"/>
        <source>Options</source>
        <translation>Opcions </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="623"/>
        <source>Repair a user configuration</source>
        <translation>Repara una configuració d&apos;usuari </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="657"/>
        <location filename="../mainwindow.ui" line="1393"/>
        <source>Modify User Account</source>
        <translation>Modifica compte d&apos;usuari</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="669"/>
        <location filename="../mainwindow.ui" line="685"/>
        <source>Select user to repair</source>
        <translation>Trieu l&apos;usuari a reparar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="672"/>
        <location filename="../mainwindow.ui" line="1445"/>
        <source>User to change:</source>
        <translation>Usuari a canviar:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="717"/>
        <source>Restore Defaults</source>
        <translation>Restaura Predeterminats </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="738"/>
        <source>Restore browser configs to MX defaults</source>
        <translation>Restaura paràmetres del navegador a predeterminats de MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="744"/>
        <source>Mozilla (Iceweasel or Firefox) configs</source>
        <translation>Paràmetres de Mozilla (Iceweasel o Firefox)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="747"/>
        <source>Alt+X</source>
        <translation>Alt+X</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="754"/>
        <source>Restore group memberships to MX defaults</source>
        <translation>Restaura la pertinença a grups als predeterminats MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="760"/>
        <source>Group memberships</source>
        <translation>Pertinença a Grups </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="763"/>
        <source>Alt+G</source>
        <translation>Alt+G</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="773"/>
        <source>Change Autologin Settings</source>
        <translation>Canvia els paràmetres d&apos;Entrada Automàtica </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="779"/>
        <source>Log in automatically</source>
        <translation>Entra automàticament </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="786"/>
        <source>Require password to log in</source>
        <translation>Cal contrasenya per entrar </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="801"/>
        <source>Copy/Sync</source>
        <translation>Còpia/Sinc</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="828"/>
        <source>Copy Between Desktops</source>
        <translation>Copia entre escriptoris </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="855"/>
        <location filename="../mainwindow.ui" line="922"/>
        <source>Select desktop to copy from</source>
        <translation>Trieu l&apos;escriptori des d&apos;on copiar </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="868"/>
        <source>Select to only copy files</source>
        <translation>Marqueu per copiar només fitxers </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="871"/>
        <source>Copy only</source>
        <translation>Només copiar </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="887"/>
        <location filename="../mainwindow.ui" line="900"/>
        <source>Select desktop to copy to</source>
        <translation>Trieu l&apos;escriptori a on copiar </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="909"/>
        <source>Copy to:</source>
        <translation>Copia a: </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="931"/>
        <source>Copy from:</source>
        <translation>Copia de: </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="944"/>
        <source>Select to copy and then delete differences</source>
        <translation>Marqueu per copiar i després esborrar diferències</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="947"/>
        <source>Sync</source>
        <translation>Sinc</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="993"/>
        <source>Select to copy/sync Shared</source>
        <translation>Marqueu per copiar/sincronitzar Shared </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="996"/>
        <source>Shared folder</source>
        <translation>Directori Shared </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1009"/>
        <source>Select to copy/sync entire home</source>
        <translation>Marqueu per copiar/sinc. tot el directori d&apos;inici </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1012"/>
        <source>Entire home</source>
        <translation>Tot el directori d&apos;Inici </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1028"/>
        <source>Select to copy/sync the browser configuration</source>
        <translation>Marqueu per copiar/sinc els paràmetres del navegador </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1031"/>
        <source>Mozilla (Firefox or Iceweasel) configs</source>
        <translation>Configuració de Mozilla (Firefox o Iceweasel)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1044"/>
        <source>Select to copy/sync Documents</source>
        <translation>Marqueu per copiar/sinc. Documents</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1047"/>
        <source>Documents folder</source>
        <translation>Directori de Documents</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1054"/>
        <source>What to copy/sync:</source>
        <translation>Què copiar/sincronitzar: </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1070"/>
        <source>Progress</source>
        <translation>Progrés </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1100"/>
        <location filename="../mainwindow.ui" line="1116"/>
        <source>Status of the changes</source>
        <translation>Estat dels canvis </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1119"/>
        <source>Status:</source>
        <translation>Estat: </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1135"/>
        <source>Progress of the changes</source>
        <translation>Progrés dels canvis </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1172"/>
        <source>Add/Remove Groups</source>
        <translation>Afegeix/treu Grups</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1184"/>
        <source>Add Group</source>
        <translation>Afegeix Grup</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1211"/>
        <source>Enter name of new group</source>
        <translation>Entreu el nom del nou grup</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1217"/>
        <source>groupname</source>
        <translation>nomdegrup</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1227"/>
        <source>Create a group with GID &gt; 1000</source>
        <translation>Crea un grup amb GID &gt; 1000</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1230"/>
        <source>Create a user-level group</source>
        <translation>Crea un grup a nivell d&apos;usuari</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1259"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Enter name of new group&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Entreu el nom del nou grup&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1262"/>
        <source>Group name:</source>
        <translation>Nom del grup: </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1281"/>
        <source>Delete Group</source>
        <translation>Elimina Grup</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1350"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Select group to delete&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Trieu el grup a esborrar&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1359"/>
        <source>Select group to delete:</source>
        <translation>Trieu el grup a esborrar:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1366"/>
        <source>*Please doublecheck your selections before applying, removing a wrong group can break your system.</source>
        <translation>&quot;
*Si us plau, comproveu bé les seleccions abans d&apos;aplicar-les, eliminar un grup incorrecte pot trencar el vostre sistema.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1381"/>
        <source>Group Membership</source>
        <translation>Pertinença a grups</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1455"/>
        <source>Groups user belongs to (change the groups by selecting/deselecting the appropriate boxes):</source>
        <translation>Grups on pertany l&apos;usuari (canvieu els grups seleccionant/desseleccionant les caselles corresponents):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1478"/>
        <source>*Please doublecheck your selections before applying, assigning wrong group memberships can break your system. If you made a mistake, use restore group membership in Options tab to restore the defaults.</source>
        <translation>*Si us plau, comproveu bé la vostra tria abans d&apos;aplicar els canvis; assignar una pertinença a grup errònia pot trencar el vostre sistema. Si feu un error, useu restaura la pertinença a grup a la pestanya Opcions per restaurar els valors per omissió.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1507"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Select user to change&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Trieu l&apos;usuari a canviar&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1583"/>
        <source>Cancel any changes then quit</source>
        <translation>Cancel·la els canvis i surt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1586"/>
        <source>Close</source>
        <translation>Tanca</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1593"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1634"/>
        <source>Display help </source>
        <translation>Mostra l&apos;ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1637"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1644"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1651"/>
        <source>Apply any changes</source>
        <translation>Aplica els canvis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1654"/>
        <source>Apply</source>
        <translation>Aplica</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1661"/>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1668"/>
        <source>About this application</source>
        <translation>Quant al programa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1671"/>
        <source>About...</source>
        <translation>Quant a...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1678"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="108"/>
        <location filename="../mainwindow.cpp" line="155"/>
        <location filename="../mainwindow.cpp" line="163"/>
        <location filename="../mainwindow.cpp" line="181"/>
        <location filename="../mainwindow.cpp" line="190"/>
        <location filename="../mainwindow.cpp" line="198"/>
        <location filename="../mainwindow.cpp" line="757"/>
        <location filename="../mainwindow.cpp" line="783"/>
        <location filename="../mainwindow.cpp" line="813"/>
        <location filename="../mainwindow.cpp" line="970"/>
        <location filename="../mainwindow.cpp" line="1037"/>
        <location filename="../mainwindow.cpp" line="1044"/>
        <location filename="../mainwindow.cpp" line="1049"/>
        <location filename="../mainwindow.cpp" line="1054"/>
        <location filename="../mainwindow.cpp" line="1059"/>
        <source>none</source>
        <translation>cap</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="140"/>
        <location filename="../mainwindow.cpp" line="744"/>
        <location filename="../mainwindow.cpp" line="977"/>
        <location filename="../mainwindow.cpp" line="986"/>
        <source>browse...</source>
        <translation>navega...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="209"/>
        <source>The user configuration will be repaired. Please close all other applications now. When finished, please logout or reboot. Are you sure you want to repair now?</source>
        <translation>Es repararà la configuració d&apos;usuari. Si us plau, tanqueu tots els altres programes. En acabar, torneu a entrar o arrencar. Esteu segur que voleu reparar-ho ara?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="231"/>
        <source>User group membership was restored.</source>
        <translation>S&apos;ha restaurat l&apos;afiliació al grup d&apos;usuaris.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="236"/>
        <source>Mozilla settings were reset.</source>
        <translation>S&apos;han reiniciat els paràmetres de Mozilla.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="247"/>
        <location filename="../mainwindow.cpp" line="263"/>
        <source>Autologin options</source>
        <translation>Opcions d&apos;entrada automàtica </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="248"/>
        <source>Autologin has been disabled for the &apos;%1&apos; account.</source>
        <translation>S&apos;ha desactivat l&apos;entrada automàtica per al compte &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="264"/>
        <source>Autologin has been enabled for the &apos;%1&apos; account.</source>
        <translation>S&apos;ha activat l&apos;entrada automàtica per al compte &apos;%1&apos; </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="276"/>
        <source>You must specify a &apos;copy to&apos; destination. You cannot copy to the desktop you are logged in to.</source>
        <translation>Cal que especifiqueu un lloc de destinació. No podeu copiar-ho a l&apos;escriptori on esteu registrat.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="282"/>
        <source>Before copying, close all other applications. Be sure the copy to destination is large enough to contain the files you are copying. Copying between desktops may overwrite or delete your files or preferences on the destination desktop. Are you sure you want to proceed?</source>
        <translation>Abans de copiar, cal tancar tots els altres programes. Assegureu-vos que la destinació té prou lloc per encabir tots els fitxers que copiareu. Copiar entre escriptoris pot sobreescriure o esborrar fitxers o preferències a l&apos;escriptori destinació. Esteu segur que voleu continuar?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="308"/>
        <source>Synchronizing desktop...</source>
        <translation>Sincronitzant l&apos;escriptori...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="310"/>
        <source>Copying desktop...</source>
        <translation>Copiant l&apos;escriptori...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="347"/>
        <location filename="../mainwindow.cpp" line="574"/>
        <source>The user name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation>El nom d&apos;usuari ha de tenir com a mínim 2 caràcters. Si us plau, trieu un nom més llarg abans de continuar.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="352"/>
        <source>The user name cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>El nom d&apos;usuari no pot contenir caràcters especials ni espais.
Si us plau, trieu-ne un altre abans de continuar.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="358"/>
        <source>Sorry, this name is in use. Please enter a different name.</source>
        <translation>Ho sento, aquest nom ja està en ús. Si us plau, trieu-ne un altre.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="362"/>
        <location filename="../mainwindow.cpp" line="417"/>
        <source>Password entries do not match. Please try again.</source>
        <translation>Les contrasenyes no coincideixen. Si us plau, torneu-ho a provar.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="367"/>
        <location filename="../mainwindow.cpp" line="422"/>
        <source>Password needs to be at least 2 characters long. Please enter a longer password before proceeding.</source>
        <translation>La contrasenya ha de tenir 2 caràcters com a mínim. Si us plau, entreu una contrasenya més llarga abans de continuar.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="406"/>
        <source>The user was added ok.</source>
        <translation>Usuari afegit correctament.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="409"/>
        <source>Failed to add the user.</source>
        <translation>Ha fallat en afegir l&apos;usuari.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="437"/>
        <source>Password successfully changed.</source>
        <translation>La contrasenya s&apos;ha canviat correctament.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="440"/>
        <source>Failed to change password.</source>
        <translation>Ha fallat el canvi de contrasenya.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="446"/>
        <source>This action cannot be undone. Are you sure you want to delete user %1?</source>
        <translation>Aquesta acció no es pot desfer. Esteu segur de voler eliminar l&apos;usuari %1? </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="464"/>
        <source>The user has been deleted.</source>
        <translation>S&apos;ha eliminat l&apos;usuari.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="466"/>
        <source>Failed to delete the user.</source>
        <translation>No he pogut eliminar l&apos;usuari.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="480"/>
        <source>The group name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation>El nom de grup ha de tenir com a mínim 2 caràcters. Si us plau, trieu un nom més llarg abans de continuar.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="485"/>
        <source>The group name needs to be lower case and it 
cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>El nom de grup ha d&apos;estar en minúscules i no
pot contenir espais ni caràcters especials.
Si us plau, trieu un altre nom abans de continuar.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="493"/>
        <source>Sorry, that group name already exists. Please enter a different name.</source>
        <translation>Ho sento, aquest nom de grup ja està en ús. Si us plau, trieu-ne un altre.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="501"/>
        <source>The system group was added ok.</source>
        <translation>S&apos;ha afegit el grup de sistema correctament.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="503"/>
        <source>Failed to add the system group.</source>
        <translation>Ha fallat en afegir el grup de sistema. </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="518"/>
        <source>This action cannot be undone. Are you sure you want to delete group %1?</source>
        <translation>Aquesta acció no es pot desfer. Esteu segur de voler eliminar el grup %1? </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="519"/>
        <source>This action cannot be undone. Are you sure you want to delete the following groups: %1?</source>
        <translation>Aquesta acció no es pot desfer. Esteu segur que voleu eliminar els següents grups: %1?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="528"/>
        <source>Failed to delete the group.</source>
        <translation>Error en eliminar el grup.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="528"/>
        <source>Group: %1</source>
        <translation>Grup: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="532"/>
        <source>The group has been deleted.</source>
        <translation>S&apos;ha eliminat el grup.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="532"/>
        <source>The groups have been deleted.</source>
        <translation>S&apos;han esborrat els grups.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="549"/>
        <source>The changes have been applied.</source>
        <translation>S&apos;han aplicat els canvis.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="551"/>
        <source>Failed to apply group changes</source>
        <translation>Error en aplicar els canvis de grup</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="565"/>
        <source>The selected user name is currently in use.</source>
        <translation>El nom d&apos;usuari escollit ja està en ús.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="566"/>
        <source>To rename this user, please log out and log back in using another user account.</source>
        <translation>Per reanomenar aquest usuari, si us plau sortiu i torneu a entrar usant un altre compte d&apos;usuari.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="579"/>
        <source>The user name needs to be lower case and it
cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>El nom d&apos;usuari ha d&apos;estar en minúscules i no
pot contenir espais ni caràcters especials.
Si us plau, trieu un altre nom abans de continuar.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="586"/>
        <source>Sorry, this name already exists on your system. Please enter a different name.</source>
        <translation>Ho sento, aquest nom ja hi és al vostre sistema. Si us plau, trieu-ne un altre.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="595"/>
        <source>Failed to rename the user. Please make sure that the user is not logged in, you might need to restart</source>
        <translation>Ha fallat en reanomenar l&apos;usuari. Si us plau, assegureu-vos que aquest usuari no estigui connectat, o us caldrà tornar a arrencar.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="619"/>
        <source>The user was renamed.</source>
        <translation>S&apos;ha reanomenat l&apos;usuari.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="631"/>
        <location filename="../mainwindow.cpp" line="659"/>
        <source>Synchronizing desktop...ok</source>
        <translation>Sincronitzant escriptori... Bé</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="633"/>
        <location filename="../mainwindow.cpp" line="661"/>
        <source>Copying desktop...ok</source>
        <translation>Copiant l&apos;escriptori... Bé</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="665"/>
        <source>Synchronizing desktop...failed</source>
        <translation>Sincronitzant l&apos;escriptori... fallat</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="667"/>
        <source>Copying desktop...failed</source>
        <translation>Copiant escriptori... fallat</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="686"/>
        <source>Confirmation</source>
        <translation>Confirmació</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="687"/>
        <source>Process not done. Are you sure you want to quit the application?</source>
        <translation>No s&apos;ha acabat el procés. Esteu segurs que voleu sortir de l&apos;aplicació?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="942"/>
        <source>About %1</source>
        <translation>Quant a %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="943"/>
        <source>Version: </source>
        <translation>Versió: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="944"/>
        <source>Simple user configuration for MX Linux</source>
        <translation>Configuració d&apos;Usuari simple per MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="946"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="947"/>
        <source>%1 License</source>
        <translation>Llicència de %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="961"/>
        <source>%1 Help</source>
        <translation>Ajuda de %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="978"/>
        <source>Select folder to copy to</source>
        <translation>Trieu el directori a on copiar</translation>
    </message>
</context>
<context>
    <name>PassEdit</name>
    <message>
        <location filename="../passedit.cpp" line="162"/>
        <source>Negligible</source>
        <translation>Negligible</translation>
    </message>
    <message>
        <location filename="../passedit.cpp" line="162"/>
        <source>Very weak</source>
        <translation>Molt feble</translation>
    </message>
    <message>
        <location filename="../passedit.cpp" line="162"/>
        <source>Weak</source>
        <translation>Feble</translation>
    </message>
    <message>
        <location filename="../passedit.cpp" line="163"/>
        <source>Moderate</source>
        <translation>Moderada</translation>
    </message>
    <message>
        <location filename="../passedit.cpp" line="163"/>
        <source>Strong</source>
        <translation>Forta</translation>
    </message>
    <message>
        <location filename="../passedit.cpp" line="163"/>
        <source>Very strong</source>
        <translation>Molt Forta</translation>
    </message>
    <message>
        <location filename="../passedit.cpp" line="164"/>
        <source>Password strength: %1</source>
        <translation>Robustesa de la contrasenya: %1</translation>
    </message>
    <message>
        <location filename="../passedit.cpp" line="200"/>
        <source>Hide the password</source>
        <translation>Amaga la contrasenya</translation>
    </message>
    <message>
        <location filename="../passedit.cpp" line="200"/>
        <source>Show the password</source>
        <translation>Mostra la contrasenya</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="50"/>
        <source>License</source>
        <translation>Llicència</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="51"/>
        <location filename="../about.cpp" line="61"/>
        <source>Changelog</source>
        <translation>Registre de canvis</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="74"/>
        <source>&amp;Close</source>
        <translation>Tan&amp;ca </translation>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <location filename="../main.cpp" line="68"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="62"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Sembla que esteu connectat com a administrador, si us plau sortiu i connecteu-vos com a usuari normal per a usar aquest programa.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="69"/>
        <source>You must run this program with admin access.</source>
        <translation>Cal executar aquest programa com a administrador.</translation>
    </message>
</context>
</TS>
